<?php

class TravelDuck_ShortCodes {







  /*
   *   _____         _  _    _         _  _
   *  |_   _|       (_)| |  (_)       | |(_)
   *    | |   _ __   _ | |_  _   __ _ | | _  ___   ___
   *    | |  | '_ \ | || __|| | / _` || || |/ __| / _ \
   *   _| |_ | | | || || |_ | || (_| || || |\__ \|  __/
   *  |_____||_| |_||_| \__||_| \__,_||_||_||___/ \___|
   *
   */

  function __construct(){

    // Enqueue required resources
    add_action("wp_head", array($this, "enqueue_front_end_stylesheet") );

    // Add short codes
    add_shortcode("travelduck-onlinebooking", array($this, "shortcode_onlineBooking"));
    add_shortcode("travelduck-availability", array($this, "shortcode_availabilityCalendar"));

    // Initialise admin functionality
    add_action("admin_init", array($this, "admin_init"));
  }


  function admin_init() {

    // Only hook up these filters if:
    //   + We're in the admin panel
    //   + The current user has permission to edit posts and pages
    if(current_user_can("edit_posts") && current_user_can("edit_pages")) {
      add_filter("mce_buttons", array($this, "filter_mce_button"));
      add_filter("mce_external_plugins", array($this, "filter_mce_plugin"));
    }
  }


  /**
   * Load front facing stylesheet
   * @since 0.1.0
   */
  function enqueue_front_end_stylesheet(){
    wp_enqueue_script("travelduck", "https://travelduck.co/libraries/widgets/loader.js" );
  }




  /*
   *    _____  _                   _         _____            _
   *   / ____|| |                 | |       / ____|          | |
   *  | (___  | |__    ___   _ __ | |_     | |      ___    __| |  ___  ___
   *   \___ \ | '_ \  / _ \ | '__|| __|    | |     / _ \  / _` | / _ \/ __|
   *   ____) || | | || (_) || |   | |_     | |____| (_) || (_| ||  __/\__ \
   *  |_____/ |_| |_| \___/ |_|    \__|     \_____|\___/  \__,_| \___||___/
   *
   */


  /**
   * Online Booking Widget ShortCode.
   *
   * @param $attributes
   * @return string
   */
  function shortcode_onlineBooking($attributes) {

    $attributes = shortcode_atts(array(
      "property-id" => "1"
    ), $attributes, "travelduck");

    $propertyId = wp_strip_all_tags($attributes["property-id"]);

    $html = "
    <div style='text-align: center'>
      <div style='clear: both; max-width: 350px; display: inline-block; background-color: #fff; padding: 20px; border: 1px solid rgb(234, 234, 234); border-radius: 5px; box-shadow: 0 5px 10px rgba(0,0,0,.05)'>
        <div class=\"travelduck onlineBookingBlock\" data-property-id=\"{$propertyId}\"></div>
      </div>
    </div>";

    return $html;
  }


  /**
   * Availability Calendar Widget ShortCode.
   *
   * @param $attributes
   * @return string
   */
  function shortcode_availabilityCalendar($attributes) {

    $attributes = shortcode_atts(array(
      "property-id" => "1",
      "number-of-months-to-display" => 4,
      "week-change-over-day" => 6,
    ), $attributes, "travelduck");

    $propertyId = wp_strip_all_tags($attributes["property-id"]);
    $numberOfMonths = wp_strip_all_tags($attributes["number-of-months-to-display"]);
    $weekChangeOverDay = wp_strip_all_tags($attributes["week-change-over-day"]);

    $html = "
    <div class=\"travelduck availability\"
      data-property-id=\"{$propertyId}\"
      data-number-of-months-to-display=\"{$numberOfMonths}\"
      data-week-change-over-day=\"{$weekChangeOverDay}\"></div>
    <div style=\"clear: both\"></div>";

    return $html;
  }



  /*
   *   _______           _       ______     _  _  _                   ____          _    _
   *  |__   __|         | |     |  ____|   | |(_)| |                 |  _ \        | |  | |
   *     | |  ___ __  __| |_    | |__    __| | _ | |_  ___   _ __    | |_) | _   _ | |_ | |_  ___   _ __   ___
   *     | | / _ \\ \/ /| __|   |  __|  / _` || || __|/ _ \ | '__|   |  _ < | | | || __|| __|/ _ \ | '_ \ / __|
   *     | ||  __/ >  < | |_    | |____| (_| || || |_| (_) || |      | |_) || |_| || |_ | |_| (_) || | | |\__ \
   *     |_| \___|/_/\_\ \__|   |______|\__,_||_| \__|\___/ |_|      |____/  \__,_| \__| \__|\___/ |_| |_||___/
   *
   */


  function filter_mce_button( $buttons ) {
    // add a separation before our button, here our button's id is &quot;mygallery_button&quot;
    array_push($buttons, "|", "travelduck" );
    return $buttons;
  }

  function filter_mce_plugin( $plugins ) {
    $plugins["travelduck"] = plugin_dir_url(__FILE__) . "../js/text-editor-plugin.js";
    return $plugins;
  }


}


new TravelDuck_ShortCodes();